@@ -130,7 +130,7 @@ def submit(op : qsharp.QSharpCallable, **params) -> AzureJob:
 
 def execute(op : qsharp.QSharpCallable, **params) -> Dict:
     """
-    Executes a job in an Azure Quantum workspace.
+    Submits a job to an Azure Quantum workspace and waits for completion.
     See https://docs.microsoft.com/qsharp/api/iqsharp-magic/azure.execute for more details.
     """
     result = qsharp.client._execute_callable_magic("azure.execute", op, raise_on_stderr=False, **params)
@@ -155,11 +155,11 @@ def output(jobId : str = '', **params) -> Dict:
     if "error_code" in result: raise AzureError(result)
     return result
 
-def jobs(filter : str = '', **params) -> List[AzureJob]:
+def jobs(filter : str = '', count : int = 30, **params) -> List[AzureJob]:
     """
     Displays a list of jobs in the current Azure Quantum workspace.
     See https://docs.microsoft.com/qsharp/api/iqsharp-magic/azure.jobs for more details.
     """
-    result = qsharp.client._execute_magic(f"azure.jobs \"{filter}\"", raise_on_stderr=False, **params)
+    result = qsharp.client._execute_magic(f"azure.jobs \"{filter}\" count={count}", raise_on_stderr=False, **params)
     if "error_code" in result: raise AzureError(result)
     return [AzureJob(job) for job in result]
